You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by se...@apache.org on 2017/04/02 17:20:37 UTC

svn commit: r1789899 - in /directory/studio/trunk: plugins/ldapservers.apacheds/ plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/ plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/mode...

Author: seelmann
Date: Sun Apr  2 17:20:37 2017
New Revision: 1789899

URL: http://svn.apache.org/viewvc?rev=1789899&view=rev
Log:
DIRSERVER-2186: Fix repair command in Studio
* Fix interaction with ApacheDS "repair" command
* Rename "Start and Repair" action to only "Repair" action
* Add repair status and view repairing action in Server view
* Enable repair action menu item only if server is stopped

Added:
    directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/RepairAction.java
      - copied, changed from r1789898, directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/StartAndRepairAction.java
    directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/RepairRunnable.java
      - copied, changed from r1789898, directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/StartAndRepairRunnable.java
Removed:
    directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/StartAndRepairAction.java
    directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/StartAndRepairRunnable.java
Modified:
    directory/studio/trunk/plugins/ldapservers.apacheds/plugin.properties
    directory/studio/trunk/plugins/ldapservers.apacheds/plugin.xml
    directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/ApacheDS200LdapServerAdapter.java
    directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/messages.properties
    directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/model/LdapServerStatus.java
    directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersTableViewer.java
    directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersView.java
    directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersViewLabelProvider.java
    directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/messages.properties
    directory/studio/trunk/tests/test.integration.ui/src/main/java/org/apache/directory/studio/test/integration/ui/ApacheDSPluginTest.java
    directory/studio/trunk/tests/test.integration.ui/src/main/java/org/apache/directory/studio/test/integration/ui/bots/ApacheDSServersViewBot.java

Modified: directory/studio/trunk/plugins/ldapservers.apacheds/plugin.properties
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/ldapservers.apacheds/plugin.properties?rev=1789899&r1=1789898&r2=1789899&view=diff
==============================================================================
--- directory/studio/trunk/plugins/ldapservers.apacheds/plugin.properties (original)
+++ directory/studio/trunk/plugins/ldapservers.apacheds/plugin.properties Sun Apr  2 17:20:37 2017
@@ -24,5 +24,5 @@ LdapServerAdapter_version=2.0.0
 
 ActionCreateConnection_id=org.apache.directory.studio.ldapservers.apacheds.CreateConnectionAction
 ActionCreateConnection_label=Create a Connection
-ActionStartAndRepair_id=org.apache.directory.studio.ldapservers.apacheds.StartAndRepairAction
-ActionStartAndRepair_label=Start and Repair
\ No newline at end of file
+ActionRepair_id=org.apache.directory.studio.ldapservers.apacheds.RepairAction
+ActionRepair_label=Repair
\ No newline at end of file

Modified: directory/studio/trunk/plugins/ldapservers.apacheds/plugin.xml
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/ldapservers.apacheds/plugin.xml?rev=1789899&r1=1789898&r2=1789899&view=diff
==============================================================================
--- directory/studio/trunk/plugins/ldapservers.apacheds/plugin.xml (original)
+++ directory/studio/trunk/plugins/ldapservers.apacheds/plugin.xml Sun Apr  2 17:20:37 2017
@@ -43,10 +43,10 @@
                icon="resources/icons/connection_new.gif">
          </action>
          <action
-               class="org.apache.directory.studio.ldapservers.apacheds.StartAndRepairAction"
+               class="org.apache.directory.studio.ldapservers.apacheds.RepairAction"
                enablesFor="1"
-               id="%ActionStartAndRepair_id"
-               label="%ActionStartAndRepair_label">
+               id="%ActionRepair_id"
+               label="%ActionRepair_label">
          </action>
          <visibility>
             <and>

Modified: directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/ApacheDS200LdapServerAdapter.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/ApacheDS200LdapServerAdapter.java?rev=1789899&r1=1789898&r2=1789899&view=diff
==============================================================================
--- directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/ApacheDS200LdapServerAdapter.java (original)
+++ directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/ApacheDS200LdapServerAdapter.java Sun Apr  2 17:20:37 2017
@@ -44,6 +44,7 @@ import org.apache.directory.studio.ldaps
 import org.apache.directory.studio.ldapservers.LdapServersUtils;
 import org.apache.directory.studio.ldapservers.model.LdapServer;
 import org.apache.directory.studio.ldapservers.model.LdapServerAdapter;
+import org.apache.directory.studio.ldapservers.model.LdapServerStatus;
 import org.apache.mina.util.AvailablePortFinder;
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.NullProgressMonitor;
@@ -179,7 +180,11 @@ public class ApacheDS200LdapServerAdapte
      */
     public void repair( LdapServer server, StudioProgressMonitor monitor ) throws Exception
     {
+        // repair
         startOrRepair( server, monitor, true );
+
+        // stop the console printer thread
+        LdapServersUtils.stopConsolePrinterThread( server );
     }
 
 
@@ -201,11 +206,34 @@ public class ApacheDS200LdapServerAdapte
         // Launching ApacheDS
         ILaunch launch = launchApacheDS( server, repair );
 
-        // Starting the "terminate" listener thread
-        LdapServersUtils.startTerminateListenerThread( server, launch );
+        if ( repair )
+        {
+            // Starting the "terminate" listener thread
+            LdapServersUtils.startTerminateListenerThread( server, launch );
+
+            // Await termination of the repair action
+            long startTime = System.currentTimeMillis();
+            final long watchDog = startTime + ( 1000 * 60 * 3 ); // 3 minutes
+            while ( ( System.currentTimeMillis() < watchDog ) && ( LdapServerStatus.REPAIRING == server.getStatus() ) )
+            {
+                try
+                {
+                    Thread.sleep( 1000 );
+                }
+                catch ( InterruptedException e1 )
+                {
+                    // Nothing to do...
+                }
+            }
+        }
+        else
+        {
+            // Starting the "terminate" listener thread
+            LdapServersUtils.startTerminateListenerThread( server, launch );
 
-        // Running the startup listener watchdog
-        LdapServersUtils.runStartupListenerWatchdog( server, getTestingPort( server ) );
+            // Running the startup listener watchdog
+            LdapServersUtils.runStartupListenerWatchdog( server, getTestingPort( server ) );
+        }
     }
     
     /**

Copied: directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/RepairAction.java (from r1789898, directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/StartAndRepairAction.java)
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/RepairAction.java?p2=directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/RepairAction.java&p1=directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/StartAndRepairAction.java&r1=1789898&r2=1789899&rev=1789899&view=diff
==============================================================================
--- directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/StartAndRepairAction.java (original)
+++ directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/RepairAction.java Sun Apr  2 17:20:37 2017
@@ -23,6 +23,7 @@ package org.apache.directory.studio.ldap
 
 import org.apache.directory.studio.ldapservers.jobs.StudioLdapServerJob;
 import org.apache.directory.studio.ldapservers.model.LdapServer;
+import org.apache.directory.studio.ldapservers.model.LdapServerStatus;
 import org.apache.directory.studio.ldapservers.views.ServersView;
 import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.viewers.ISelection;
@@ -36,7 +37,7 @@ import org.eclipse.ui.IWorkbenchPart;
  *
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public class StartAndRepairAction implements IObjectActionDelegate
+public class RepairAction implements IObjectActionDelegate
 {
     /** The {@link ServersView} */
     private ServersView view;
@@ -45,25 +46,18 @@ public class StartAndRepairAction implem
     @Override
     public void run( IAction action )
     {
-        if ( view != null )
+        LdapServer server = getSelectedServer();
+        if ( server != null )
         {
-            // Getting the selection
-            StructuredSelection selection = ( StructuredSelection ) view.getViewer().getSelection();
-            if ( ( !selection.isEmpty() ) && ( selection.size() == 1 ) )
+            // Checking that the server is really an ApacheDS 2.0.0 server
+            if ( !ExtensionUtils.verifyApacheDs200OrPrintError( server, view ) )
             {
-                // Getting the server
-                LdapServer server = ( LdapServer ) selection.getFirstElement();
-
-                // Checking that the server is really an ApacheDS 2.0.0 server
-                if ( !ExtensionUtils.verifyApacheDs200OrPrintError( server, view ) )
-                {
-                    return;
-                }
-
-                // Creating and scheduling the job to start the server
-                StudioLdapServerJob job = new StudioLdapServerJob( new StartAndRepairRunnable( server ) );
-                job.schedule();
+                return;
             }
+
+            // Creating and scheduling the job to start the server
+            StudioLdapServerJob job = new StudioLdapServerJob( new RepairRunnable( server ) );
+            job.schedule();
         }
     }
 
@@ -73,7 +67,8 @@ public class StartAndRepairAction implem
      */
     public void selectionChanged( IAction action, ISelection selection )
     {
-        // Nothing to do
+        LdapServer server = getSelectedServer();
+        action.setEnabled( server != null && server.getStatus() == LdapServerStatus.STOPPED );
     }
 
 
@@ -89,4 +84,22 @@ public class StartAndRepairAction implem
         }
     }
 
+
+    private LdapServer getSelectedServer()
+    {
+        if ( view != null )
+        {
+            // Getting the selection
+            StructuredSelection selection = ( StructuredSelection ) view.getViewer().getSelection();
+            if ( ( !selection.isEmpty() ) && ( selection.size() == 1 ) )
+            {
+                // Getting the server
+                LdapServer server = ( LdapServer ) selection.getFirstElement();
+                return server;
+            }
+        }
+
+        return null;
+    }
+
 }

Copied: directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/RepairRunnable.java (from r1789898, directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/StartAndRepairRunnable.java)
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/RepairRunnable.java?p2=directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/RepairRunnable.java&p1=directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/StartAndRepairRunnable.java&r1=1789898&r2=1789899&rev=1789899&view=diff
==============================================================================
--- directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/messages.properties (original)
+++ directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/messages.properties Sun Apr  2 17:20:37 2017
@@ -33,5 +33,5 @@ CreateConnectionAction.NotA200Server=Thi
 CreateConnectionAction.UnableCreateConnection=Unable to create a connection
 CreateConnectionAction.UnableReadServerConfiguration=Unable to read the server configuration.
 
-StartAndRepairRunnable.UnableToStartAndRepair=Unable to start and repair {0}
-StartAndRepairRunnable.StartAndRepair=Start and Repair {0}
\ No newline at end of file
+RepairRunnable.UnableToRepair=Unable to repair {0}
+RepairRunnable.Repair=Repair {0}
\ No newline at end of file

Modified: directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/model/LdapServerStatus.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/model/LdapServerStatus.java?rev=1789899&r1=1789898&r2=1789899&view=diff
==============================================================================
--- directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/model/LdapServerStatus.java (original)
+++ directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/model/LdapServerStatus.java Sun Apr  2 17:20:37 2017
@@ -27,5 +27,5 @@ package org.apache.directory.studio.ldap
  */
 public enum LdapServerStatus
 {
-    STARTED, STARTING, STOPPED, STOPPING, UNKNOWN
+    STARTED, STARTING, STOPPED, STOPPING, UNKNOWN, REPAIRING
 }

Modified: directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersTableViewer.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersTableViewer.java?rev=1789899&r1=1789898&r2=1789899&view=diff
==============================================================================
--- directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersTableViewer.java (original)
+++ directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersTableViewer.java Sun Apr  2 17:20:37 2017
@@ -155,7 +155,8 @@ public class ServersTableViewer extends
                         // If the state is STARTING or STOPPING, we need to
                         // add the server to the list of servers needing
                         // animation and eventually start the animation thread
-                        if ( ( state == LdapServerStatus.STARTING ) || ( state == LdapServerStatus.STOPPING ) )
+                        if ( ( state == LdapServerStatus.STARTING ) || ( state == LdapServerStatus.STOPPING )
+                            || ( state == LdapServerStatus.REPAIRING ) )
                         {
                             boolean startAnimationThread = false;
 

Modified: directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersView.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersView.java?rev=1789899&r1=1789898&r2=1789899&view=diff
==============================================================================
--- directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersView.java (original)
+++ directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersView.java Sun Apr  2 17:20:37 2017
@@ -433,6 +433,7 @@ public class ServersView extends ViewPar
                     start.setEnabled( false );
                     stop.setEnabled( true );
                     break;
+                case REPAIRING:
                 case STARTING:
                     start.setEnabled( false );
                     stop.setEnabled( false );

Modified: directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersViewLabelProvider.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersViewLabelProvider.java?rev=1789899&r1=1789898&r2=1789899&view=diff
==============================================================================
--- directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersViewLabelProvider.java (original)
+++ directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/ServersViewLabelProvider.java Sun Apr  2 17:20:37 2017
@@ -72,6 +72,8 @@ public class ServersViewLabelProvider ex
                         return Messages.getString( "ServersViewLabelProvider.Stopping" ) + getDots(); //$NON-NLS-1$
                     case UNKNOWN:
                         return Messages.getString( "ServersViewLabelProvider.Unknown" ); //$NON-NLS-1$
+                    case REPAIRING:
+                        return Messages.getString( "ServersViewLabelProvider.Repairing" ) + getDots(); //$NON-NLS-1$
                 }
             }
 
@@ -121,6 +123,7 @@ public class ServersViewLabelProvider ex
                 {
                     case STARTED:
                         return LdapServersPlugin.getDefault().getImage( LdapServersPluginConstants.IMG_SERVER_STARTED );
+                    case REPAIRING:
                     case STARTING:
                         switch ( dotsCount )
                         {

Modified: directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/messages.properties
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/messages.properties?rev=1789899&r1=1789898&r2=1789899&view=diff
==============================================================================
--- directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/messages.properties (original)
+++ directory/studio/trunk/plugins/ldapservers/src/main/java/org/apache/directory/studio/ldapservers/views/messages.properties Sun Apr  2 17:20:37 2017
@@ -21,6 +21,7 @@ ServersView.state=State
 
 ServersViewLabelProvider.Started=Started
 ServersViewLabelProvider.Starting=Starting
+ServersViewLabelProvider.Repairing=Repairing
 ServersViewLabelProvider.Stopped=Stopped
 ServersViewLabelProvider.Stopping=Stopping
 ServersViewLabelProvider.Unknown=Unknown
\ No newline at end of file

Modified: directory/studio/trunk/tests/test.integration.ui/src/main/java/org/apache/directory/studio/test/integration/ui/ApacheDSPluginTest.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/tests/test.integration.ui/src/main/java/org/apache/directory/studio/test/integration/ui/ApacheDSPluginTest.java?rev=1789899&r1=1789898&r2=1789899&view=diff
==============================================================================
--- directory/studio/trunk/tests/test.integration.ui/src/main/java/org/apache/directory/studio/test/integration/ui/ApacheDSPluginTest.java (original)
+++ directory/studio/trunk/tests/test.integration.ui/src/main/java/org/apache/directory/studio/test/integration/ui/ApacheDSPluginTest.java Sun Apr  2 17:20:37 2017
@@ -396,14 +396,18 @@ public class ApacheDSPluginTest
      * Test for DIRSTUDIO-1118: Run repair
      */
     @Test
-    public void startAndRepair()
+    public void repairAndStartAndStop()
     {
-        String serverName = "StartAndRepair";
+        String serverName = "Repair";
         createServer( serverName );
         setAvailablePorts( serverName );
 
-        // Start and repair the server
-        serversViewBot.startAndRepairServer( serverName );
+        // Repair the server
+        serversViewBot.repairServer( serverName );
+        serversViewBot.waitForServerStop( serverName );
+
+        // Start the server after repair
+        serversViewBot.runServer( serverName );
         serversViewBot.waitForServerStart( serverName );
 
         // TODO: newer version of ApacheDS may log to console

Modified: directory/studio/trunk/tests/test.integration.ui/src/main/java/org/apache/directory/studio/test/integration/ui/bots/ApacheDSServersViewBot.java
URL: http://svn.apache.org/viewvc/directory/studio/trunk/tests/test.integration.ui/src/main/java/org/apache/directory/studio/test/integration/ui/bots/ApacheDSServersViewBot.java?rev=1789899&r1=1789898&r2=1789899&view=diff
==============================================================================
--- directory/studio/trunk/tests/test.integration.ui/src/main/java/org/apache/directory/studio/test/integration/ui/bots/ApacheDSServersViewBot.java (original)
+++ directory/studio/trunk/tests/test.integration.ui/src/main/java/org/apache/directory/studio/test/integration/ui/bots/ApacheDSServersViewBot.java Sun Apr  2 17:20:37 2017
@@ -140,15 +140,15 @@ public class ApacheDSServersViewBot
     
     
     /**
-     * Starts and repairs the server associated with the given name.
+     * Repairs the server associated with the given name.
      *
      * @param serverName
      *      the name of the server
      */
-    public void startAndRepairServer( String serverName )
+    public void repairServer( String serverName )
     {
         selectServer( serverName );
-        ContextMenuHelper.clickContextMenu( getServersTree(), "Start and Repair" );
+        ContextMenuHelper.clickContextMenu( getServersTree(), "Repair" );
     }
--- directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/StartAndRepairRunnable.java (original)
+++ directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/RepairRunnable.java Sun Apr  2 17:20:37 2017
@@ -34,7 +34,7 @@ import org.eclipse.osgi.util.NLS;
  * 
  * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
  */
-public class StartAndRepairRunnable implements StudioRunnableWithProgress
+public class RepairRunnable implements StudioRunnableWithProgress
 {
     /** The server */
     private LdapServer server;
@@ -46,7 +46,7 @@ public class StartAndRepairRunnable impl
      * @param server
      *            the LDAP Server
      */
-    public StartAndRepairRunnable( LdapServer server )
+    public RepairRunnable( LdapServer server )
     {
         this.server = server;
     }
@@ -57,7 +57,7 @@ public class StartAndRepairRunnable impl
      */
     public String getErrorMessage()
     {
-        return NLS.bind( Messages.getString( "StartAndRepairRunnable.UnableToStartAndRepair" ), new String[] //$NON-NLS-1$
+        return NLS.bind( Messages.getString( "RepairRunnable.UnableToRepair" ), new String[] //$NON-NLS-1$
             { server.getName() } );
     }
 
@@ -77,7 +77,7 @@ public class StartAndRepairRunnable impl
      */
     public String getName()
     {
-        return NLS.bind( Messages.getString( "StartAndRepairRunnable.StartAndRepair" ), new String[] //$NON-NLS-1$
+        return NLS.bind( Messages.getString( "RepairRunnable.Repair" ), new String[] //$NON-NLS-1$
             { server.getName() } );
     }
 
@@ -87,8 +87,8 @@ public class StartAndRepairRunnable impl
      */
     public void run( StudioProgressMonitor monitor )
     {
-        // Setting the status on the server to 'starting'
-        server.setStatus( LdapServerStatus.STARTING );
+        // Setting the status on the server to 'repairing'
+        server.setStatus( LdapServerStatus.REPAIRING );
 
         try
         {

Modified: directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/messages.properties
URL: http://svn.apache.org/viewvc/directory/studio/trunk/plugins/ldapservers.apacheds/src/main/java/org/apache/directory/studio/ldapservers/apacheds/messages.properties?rev=1789899&r1=1789898&r2=1789899&view=diff
==============================================================================